@@ -13,17 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
-from oslo_log import log as logging
-import six
+from oslo.config import cfg
 
 from sahara import conductor as c
+from sahara.i18n import _
+from sahara.i18n import _LI
+from sahara.openstack.common import log as logging
+from sahara.plugins.general import utils
 from sahara.plugins import provisioning as p
-from sahara.plugins import utils
-from sahara.swift import swift_helper as swift
 from sahara.topology import topology_helper as topology
-from sahara.utils import files as f
-from sahara.utils import types
+from sahara.utils import types as types
 from sahara.utils import xmlutils as x
 
 
@@ -37,26 +36,13 @@ CORE_DEFAULT = x.load_hadoop_xml_defaults(
 HDFS_DEFAULT = x.load_hadoop_xml_defaults(
     'plugins/spark/resources/hdfs-default.xml')
 
-SWIFT_DEFAULTS = swift.read_default_swift_configs()
-
 XML_CONFS = {
-    "HDFS": [CORE_DEFAULT, HDFS_DEFAULT, SWIFT_DEFAULTS]
+    "HDFS": [CORE_DEFAULT, HDFS_DEFAULT]
 }
 
-_default_executor_classpath = ":".join(
-    ['/usr/lib/hadoop-mapreduce/hadoop-openstack.jar'])
-
 SPARK_CONFS = {
     'Spark': {
         "OPTIONS": [
-            {
-                'name': 'Executor extra classpath',
-                'description': 'Value for spark.executor.extraClassPath'
-                ' in spark-defaults.conf'
-                ' (default: %s)' % _default_executor_classpath,
-                'default': '%s' % _default_executor_classpath,
-                'priority': 2,
-            },
             {
                 'name': 'Master port',
                 'description': 'Start the master on a different port'
@@ -112,34 +98,11 @@ SPARK_CONFS = {
                 ' (default: /opt/spark)',
                 'default': '/opt/spark',
                 'priority': 2,
-            },
-            {
-                'name': 'Minimum cleanup seconds',
-                'description': 'Job data will never be purged before this'
-                ' amount of time elapses (default: 86400 = 1 day)',
-                'default': '86400',
-                'priority': 2,
-            },
-            {
-                'name': 'Maximum cleanup seconds',
-                'description': 'Job data will always be purged after this'
-                ' amount of time elapses (default: 1209600 = 14 days)',
-                'default': '1209600',
-                'priority': 2,
-            },
-            {
-                'name': 'Minimum cleanup megabytes',
-                'description': 'No job data will be purged unless the total'
-                ' job data exceeds this size (default: 4096 = 4GB)',
-                'default': '4096',
-                'priority': 2,
-            },
+            }
         ]
     }
 }
 
-HADOOP_CONF_DIR = "/etc/hadoop/conf"
-
 ENV_CONFS = {
     "HDFS": {
         'Name Node Heap Size': 'HADOOP_NAMENODE_OPTS=\\"-Xmx%sm\\"',
@@ -151,15 +114,6 @@ ENABLE_DATA_LOCALITY = p.Config('Enable Data Locality', 'general', 'cluster',
                                 config_type="bool", priority=1,
                                 default_value=True, is_optional=True)
 
-ENABLE_SWIFT = p.Config('Enable Swift', 'general', 'cluster',
-                        config_type="bool", priority=1,
-                        default_value=True, is_optional=False)
-
-DATANODES_STARTUP_TIMEOUT = p.Config(
-    'DataNodes startup timeout', 'general', 'cluster', config_type='int',
-    priority=1, default_value=10800, is_optional=True,
-    description='Timeout for DataNodes startup, in seconds')
-
 # Default set to 1 day, which is the default Keystone token
 # expiration time. After the token is expired we can't continue
 # scaling anyway.
@@ -189,7 +143,7 @@ PRIORITY_1_CONFS += CLUSTER_WIDE_CONFS
 
 def _initialise_configs():
     configs = []
-    for service, config_lists in six.iteritems(XML_CONFS):
+    for service, config_lists in XML_CONFS.iteritems():
         for config_list in config_lists:
             for config in config_list:
                 if config['name'] not in HIDDEN_CONFS:
@@ -209,13 +163,13 @@ def _initialise_configs():
                         cfg.priority = 1
                     configs.append(cfg)
 
-    for service, config_items in six.iteritems(ENV_CONFS):
-        for name, param_format_str in six.iteritems(config_items):
+    for service, config_items in ENV_CONFS.iteritems():
+        for name, param_format_str in config_items.iteritems():
             configs.append(p.Config(name, service, "node",
                                     default_value=1024, priority=1,
                                     config_type="int"))
 
-    for service, config_items in six.iteritems(SPARK_CONFS):
+    for service, config_items in SPARK_CONFS.iteritems():
         for item in config_items['OPTIONS']:
             cfg = p.Config(name=item["name"],
                            description=item["description"],
@@ -226,8 +180,6 @@ def _initialise_configs():
             configs.append(cfg)
 
     configs.append(DECOMMISSIONING_TIMEOUT)
-    configs.append(ENABLE_SWIFT)
-    configs.append(DATANODES_STARTUP_TIMEOUT)
     if CONF.enable_data_locality:
         configs.append(ENABLE_DATA_LOCALITY)
 
@@ -241,6 +193,22 @@ def get_plugin_configs():
     return PLUGIN_CONFIGS
 
 
+def get_config_value(service, name, cluster=None):
+    if cluster:
+        for ng in cluster.node_groups:
+            if (ng.configuration().get(service) and
+                    ng.configuration()[service].get(name)):
+                return ng.configuration()[service][name]
+
+    for configs in PLUGIN_CONFIGS:
+        if configs.applicable_target == service and configs.name == name:
+            return configs.default_value
+
+    raise RuntimeError(_("Unable to get parameter '%(param_name)s' from "
+                         "service %(service)s"),
+                       {'param_name': name, 'service': service})
+
+
 def generate_cfg_from_general(cfg, configs, general_config,
                               rest_excluded=False):
     if 'general' in configs:
@@ -250,7 +218,7 @@ def generate_cfg_from_general(cfg, configs, general_config,
         for name, value in configs['general'].items():
             if value:
                 cfg = _set_config(cfg, general_config, name)
-                LOG.debug("Applying config: {name}".format(name=name))
+                LOG.info(_LI("Applying config: %s"), name)
     else:
         cfg = _set_config(cfg, general_config)
     return cfg
@@ -270,25 +238,16 @@ def generate_xml_configs(configs, storage_path, nn_hostname, hadoop_port):
                                                      '/dfs/nn'),
         'dfs.datanode.data.dir': extract_hadoop_path(storage_path,
                                                      '/dfs/dn'),
-        'dfs.hosts': '/etc/hadoop/dn.incl',
-        'dfs.hosts.exclude': '/etc/hadoop/dn.excl'
+        'hadoop.tmp.dir': extract_hadoop_path(storage_path,
+                                              '/dfs'),
     }
 
     # inserting user-defined configs
     for key, value in extract_hadoop_xml_confs(configs):
         cfg[key] = value
 
-    # Add the swift defaults if they have not been set by the user
-    swft_def = []
-    if is_swift_enabled(configs):
-        swft_def = SWIFT_DEFAULTS
-        swift_configs = extract_name_values(swift.get_swift_configs())
-        for key, value in six.iteritems(swift_configs):
-            if key not in cfg:
-                cfg[key] = value
-
     # invoking applied configs to appropriate xml files
-    core_all = CORE_DEFAULT + swft_def
+    core_all = CORE_DEFAULT
 
     if CONF.enable_data_locality:
         cfg.update(topology.TOPOLOGY_CONFIG)
@@ -317,78 +276,50 @@ def generate_spark_env_configs(cluster):
     sp_master = utils.get_instance(cluster, "master")
     configs.append('SPARK_MASTER_IP=' + sp_master.hostname())
 
-    # point to the hadoop conf dir so that Spark can read things
-    # like the swift configuration without having to copy core-site
-    # to /opt/spark/conf
-    configs.append('HADOOP_CONF_DIR=' + HADOOP_CONF_DIR)
-
-    masterport = utils.get_config_value_or_default("Spark",
-                                                   "Master port",
-                                                   cluster)
+    masterport = get_config_value("Spark", "Master port", cluster)
     if masterport and masterport != _get_spark_opt_default("Master port"):
         configs.append('SPARK_MASTER_PORT=' + str(masterport))
 
-    masterwebport = utils.get_config_value_or_default("Spark",
-                                                      "Master webui port",
-                                                      cluster)
+    masterwebport = get_config_value("Spark", "Master webui port", cluster)
     if (masterwebport and
             masterwebport != _get_spark_opt_default("Master webui port")):
         configs.append('SPARK_MASTER_WEBUI_PORT=' + str(masterwebport))
 
     # configuration for workers
-    workercores = utils.get_config_value_or_default("Spark",
-                                                    "Worker cores",
-                                                    cluster)
+    workercores = get_config_value("Spark", "Worker cores", cluster)
     if workercores and workercores != _get_spark_opt_default("Worker cores"):
         configs.append('SPARK_WORKER_CORES=' + str(workercores))
 
-    workermemory = utils.get_config_value_or_default("Spark",
-                                                     "Worker memory",
-                                                     cluster)
+    workermemory = get_config_value("Spark", "Worker memory", cluster)
     if (workermemory and
             workermemory != _get_spark_opt_default("Worker memory")):
         configs.append('SPARK_WORKER_MEMORY=' + str(workermemory))
 
-    workerport = utils.get_config_value_or_default("Spark",
-                                                   "Worker port",
-                                                   cluster)
+    workerport = get_config_value("Spark", "Worker port", cluster)
     if workerport and workerport != _get_spark_opt_default("Worker port"):
         configs.append('SPARK_WORKER_PORT=' + str(workerport))
 
-    workerwebport = utils.get_config_value_or_default("Spark",
-                                                      "Worker webui port",
-                                                      cluster)
+    workerwebport = get_config_value("Spark", "Worker webui port", cluster)
     if (workerwebport and
             workerwebport != _get_spark_opt_default("Worker webui port")):
         configs.append('SPARK_WORKER_WEBUI_PORT=' + str(workerwebport))
 
-    workerinstances = utils.get_config_value_or_default("Spark",
-                                                        "Worker instances",
-                                                        cluster)
+    workerinstances = get_config_value("Spark", "Worker instances", cluster)
     if (workerinstances and
             workerinstances != _get_spark_opt_default("Worker instances")):
         configs.append('SPARK_WORKER_INSTANCES=' + str(workerinstances))
     return '\n'.join(configs)
 
 
-# workernames need to be a list of worker names
+# workernames need to be a list of woker names
 def generate_spark_slaves_configs(workernames):
     return '\n'.join(workernames)
 
 
-def generate_spark_executor_classpath(cluster):
-    cp = utils.get_config_value_or_default("Spark",
-                                           "Executor extra classpath",
-                                           cluster)
-    if cp:
-        return "spark.executor.extraClassPath " + cp
-    return "\n"
-
-
 def extract_hadoop_environment_confs(configs):
     """Returns environment specific Hadoop configurations.
 
-    :returns: list of Hadoop parameters which should be passed via environment
+    :returns list of Hadoop parameters which should be passed via environment
     """
 
     lst = []
@@ -404,8 +335,8 @@ def extract_hadoop_environment_confs(configs):
 def extract_hadoop_xml_confs(configs):
     """Returns xml specific Hadoop configurations.
 
-    :returns: list of Hadoop parameters which should be passed into general
-     configs like core-site.xml
+    :returns list of Hadoop parameters which should be passed into general
+    configs like core-site.xml
     """
 
     lst = []
@@ -440,34 +371,12 @@ def generate_hadoop_setup_script(storage_paths, env_configs):
 
     for path in storage_paths:
         script_lines.append("chown -R hadoop:hadoop %s" % path)
-        script_lines.append("chmod -f -R 755 %s ||"
-                            "echo 'Permissions unchanged'" % path)
+        script_lines.append("chmod -R 755 %s" % path)
     return "\n".join(script_lines)
 
 
-def generate_job_cleanup_config(cluster):
-    args = {
-        'minimum_cleanup_megabytes': utils.get_config_value_or_default(
-            "Spark", "Minimum cleanup megabytes", cluster),
-        'minimum_cleanup_seconds': utils.get_config_value_or_default(
-            "Spark", "Minimum cleanup seconds", cluster),
-        'maximum_cleanup_seconds': utils.get_config_value_or_default(
-            "Spark", "Maximum cleanup seconds", cluster)
-    }
-    job_conf = {'valid': (args['maximum_cleanup_seconds'] > 0 and
-                          (args['minimum_cleanup_megabytes'] > 0
-                           and args['minimum_cleanup_seconds'] > 0))}
-    if job_conf['valid']:
-        job_conf['cron'] = f.get_file_text(
-            'plugins/spark/resources/spark-cleanup.cron'),
-        job_cleanup_script = f.get_file_text(
-            'plugins/spark/resources/tmp-cleanup.sh.template')
-        job_conf['script'] = job_cleanup_script.format(**args)
-    return job_conf
-
-
 def extract_name_values(configs):
-    return {cfg['name']: cfg['value'] for cfg in configs}
+    return dict((cfg['name'], cfg['value']) for cfg in configs)
 
 
 def make_hadoop_path(base_dirs, suffix):
@@ -488,30 +397,25 @@ def _set_config(cfg, gen_cfg, name=None):
     return cfg
 
 
-def _get_general_config_value(conf, option):
+def _get_general_cluster_config_value(cluster, option):
+    conf = cluster.cluster_configs
+
     if 'general' in conf and option.name in conf['general']:
         return conf['general'][option.name]
+
     return option.default_value
 
 
-def _get_general_cluster_config_value(cluster, option):
-    return _get_general_config_value(cluster.cluster_configs, option)
-
-
 def is_data_locality_enabled(cluster):
     if not CONF.enable_data_locality:
         return False
     return _get_general_cluster_config_value(cluster, ENABLE_DATA_LOCALITY)
 
 
-def is_swift_enabled(configs):
-    return _get_general_config_value(configs, ENABLE_SWIFT)
-
-
 def get_decommissioning_timeout(cluster):
     return _get_general_cluster_config_value(cluster, DECOMMISSIONING_TIMEOUT)
 
 
 def get_port_from_config(service, name, cluster=None):
-    address = utils.get_config_value_or_default(service, name, cluster)
+    address = get_config_value(service, name, cluster)
     return utils.get_port_from_address(address)
