@@ -13,27 +13,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import copy
 import os
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 
 from sahara import conductor
 from sahara import context
 from sahara.i18n import _
-from sahara.plugins import exceptions as ex
+from sahara.i18n import _LI
+from sahara.openstack.common import log as logging
+from sahara.plugins.general import exceptions as ex
+from sahara.plugins.general import utils
 from sahara.plugins import provisioning as p
-from sahara.plugins import recommendations_utils as ru
 from sahara.plugins.spark import config_helper as c_helper
 from sahara.plugins.spark import edp_engine
 from sahara.plugins.spark import run_scripts as run
 from sahara.plugins.spark import scaling as sc
-from sahara.plugins.spark import shell_engine
-from sahara.plugins import utils
-from sahara.swift import swift_helper
 from sahara.topology import topology_helper as th
-from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import files as f
 from sahara.utils import general as ug
 from sahara.utils import remote
@@ -58,21 +54,8 @@ class SparkProvider(p.ProvisioningPluginBase):
         return _("This plugin provides an ability to launch Spark on Hadoop "
                  "CDH cluster without any management consoles.")
 
-    def get_labels(self):
-        default = {'enabled': {'status': True}, 'stable': {'status': True}}
-        deprecated = {'enabled': {'status': True},
-                      'deprecated': {'status': True}}
-        result = {'plugin_labels': copy.deepcopy(default)}
-        stable_versions = ['2.2', '2.1.0', '1.6.0']
-        result['version_labels'] = {
-            version: copy.deepcopy(
-                default if version in stable_versions else deprecated
-                ) for version in self.get_versions()
-        }
-        return result
-
     def get_versions(self):
-        return ['2.2', '2.1.0', '1.6.0', '1.3.1']
+        return ['1.0.0', '0.9.1']
 
     def get_configs(self, hadoop_version):
         return c_helper.get_plugin_configs()
@@ -92,27 +75,13 @@ class SparkProvider(p.ProvisioningPluginBase):
             raise ex.InvalidComponentCountException("datanode", _("1 or more"),
                                                     nn_count)
 
-        rep_factor = utils.get_config_value_or_default('HDFS',
-                                                       "dfs.replication",
-                                                       cluster)
-        if dn_count < rep_factor:
-            raise ex.InvalidComponentCountException(
-                'datanode', _('%s or more') % rep_factor, dn_count,
-                _('Number of %(dn)s instances should not be less '
-                  'than %(replication)s')
-                % {'dn': 'datanode', 'replication': 'dfs.replication'})
-
         # validate Spark Master Node and Spark Slaves
         sm_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "master")])
 
-        if sm_count < 1:
+        if sm_count != 1:
             raise ex.RequiredServiceMissingException("Spark master")
 
-        if sm_count >= 2:
-            raise ex.InvalidComponentCountException("Spark master", "1",
-                                                    sm_count)
-
         sl_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "slave")])
 
@@ -127,37 +96,21 @@ class SparkProvider(p.ProvisioningPluginBase):
     def configure_cluster(self, cluster):
         self._setup_instances(cluster)
 
-    @cpo.event_wrapper(
-        True, step=utils.start_process_event_message("NameNode"))
-    def _start_namenode(self, nn_instance):
+    def start_cluster(self, cluster):
+        nn_instance = utils.get_instance(cluster, "namenode")
+        sm_instance = utils.get_instance(cluster, "master")
+        dn_instances = utils.get_instances(cluster, "datanode")
+
+        # Start the name node
         with remote.get_remote(nn_instance) as r:
             run.format_namenode(r)
             run.start_processes(r, "namenode")
 
-    def start_spark(self, cluster):
-        sm_instance = utils.get_instance(cluster, "master")
-        if sm_instance:
-            self._start_spark(cluster, sm_instance)
-
-    @cpo.event_wrapper(
-        True, step=utils.start_process_event_message("SparkMasterNode"))
-    def _start_spark(self, cluster, sm_instance):
-        with remote.get_remote(sm_instance) as r:
-            run.start_spark_master(r, self._spark_home(cluster))
-            LOG.info("Spark service has been started")
-
-    def start_cluster(self, cluster):
-        nn_instance = utils.get_instance(cluster, "namenode")
-        dn_instances = utils.get_instances(cluster, "datanode")
-
-        # Start the name node
-        self._start_namenode(nn_instance)
-
         # start the data nodes
-        self._start_datanode_processes(dn_instances)
-        run.await_datanodes(cluster)
+        self._start_slave_datanode_processes(dn_instances)
 
-        LOG.info("Hadoop services have been started")
+        LOG.info(_LI("Hadoop services in cluster %s have been started"),
+                 cluster.name)
 
         with remote.get_remote(nn_instance) as r:
             r.execute_command("sudo -u hdfs hdfs dfs -mkdir -p /user/$USER/")
@@ -165,18 +118,21 @@ class SparkProvider(p.ProvisioningPluginBase):
                               "/user/$USER/")
 
         # start spark nodes
-        self.start_spark(cluster)
-        swift_helper.install_ssl_certs(utils.get_instances(cluster))
+        if sm_instance:
+            with remote.get_remote(sm_instance) as r:
+                run.start_spark_master(r, self._spark_home(cluster))
+                LOG.info(_LI("Spark service at '%s' has been started"),
+                         sm_instance.hostname())
 
-        LOG.info('Cluster has been started successfully')
+        LOG.info(_LI('Cluster %s has been started successfully'),
+                 cluster.name)
         self._set_cluster_info(cluster)
 
     def _spark_home(self, cluster):
-        return utils.get_config_value_or_default("Spark",
-                                                 "Spark home",
-                                                 cluster)
+        return c_helper.get_config_value("Spark", "Spark home", cluster)
 
     def _extract_configs_to_extra(self, cluster):
+        nn = utils.get_instance(cluster, "namenode")
         sp_master = utils.get_instance(cluster, "master")
         sp_slaves = utils.get_instances(cluster, "slave")
 
@@ -194,15 +150,21 @@ class SparkProvider(p.ProvisioningPluginBase):
         else:
             config_slaves = "\n"
 
-        # Any node that might be used to run spark-submit will need
-        # these libs for swift integration
-        config_defaults = c_helper.generate_spark_executor_classpath(cluster)
-
-        extra['job_cleanup'] = c_helper.generate_job_cleanup_config(cluster)
-
-        extra['sp_master'] = config_master
-        extra['sp_slaves'] = config_slaves
-        extra['sp_defaults'] = config_defaults
+        for ng in cluster.node_groups:
+            extra[ng.id] = {
+                'xml': c_helper.generate_xml_configs(
+                    ng.configuration(),
+                    ng.storage_paths(),
+                    nn.hostname(), None,
+                ),
+                'setup_script': c_helper.generate_hadoop_setup_script(
+                    ng.storage_paths(),
+                    c_helper.extract_hadoop_environment_confs(
+                        ng.configuration())
+                ),
+                'sp_master': config_master,
+                'sp_slaves': config_slaves
+            }
 
         if c_helper.is_data_locality_enabled(cluster):
             topology_data = th.generate_topology_map(
@@ -212,33 +174,12 @@ class SparkProvider(p.ProvisioningPluginBase):
 
         return extra
 
-    def _add_instance_ng_related_to_extra(self, cluster, instance, extra):
-        extra = extra.copy()
-        ng = instance.node_group
-        nn = utils.get_instance(cluster, "namenode")
-
-        extra['xml'] = c_helper.generate_xml_configs(
-            ng.configuration(), instance.storage_paths(), nn.hostname(), None)
-        extra['setup_script'] = c_helper.generate_hadoop_setup_script(
-            instance.storage_paths(),
-            c_helper.extract_hadoop_environment_confs(ng.configuration()))
-
-        return extra
-
-    def _start_datanode_processes(self, dn_instances):
-        if len(dn_instances) == 0:
-            return
-
-        cpo.add_provisioning_step(
-            dn_instances[0].cluster_id,
-            utils.start_process_event_message("DataNodes"), len(dn_instances))
-
+    def _start_slave_datanode_processes(self, dn_instances):
         with context.ThreadGroup() as tg:
             for i in dn_instances:
                 tg.spawn('spark-start-dn-%s' % i.instance_name,
                          self._start_datanode, i)
 
-    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _start_datanode(self, instance):
         with instance.remote() as r:
             run.start_processes(r, "datanode")
@@ -253,12 +194,8 @@ class SparkProvider(p.ProvisioningPluginBase):
 
     def _push_configs_to_nodes(self, cluster, extra, new_instances):
         all_instances = utils.get_instances(cluster)
-        cpo.add_provisioning_step(
-            cluster.id, _("Push configs to nodes"), len(all_instances))
         with context.ThreadGroup() as tg:
             for instance in all_instances:
-                extra = self._add_instance_ng_related_to_extra(
-                    cluster, instance, extra)
                 if instance in new_instances:
                     tg.spawn('spark-configure-%s' % instance.instance_name,
                              self._push_configs_to_new_node, cluster,
@@ -268,25 +205,22 @@ class SparkProvider(p.ProvisioningPluginBase):
                              self._push_configs_to_existing_node, cluster,
                              extra, instance)
 
-    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _push_configs_to_new_node(self, cluster, extra, instance):
+        ng_extra = extra[instance.node_group.id]
+
         files_hadoop = {
-            os.path.join(c_helper.HADOOP_CONF_DIR,
-                         "core-site.xml"): extra['xml']['core-site'],
-            os.path.join(c_helper.HADOOP_CONF_DIR,
-                         "hdfs-site.xml"): extra['xml']['hdfs-site'],
+            '/etc/hadoop/conf/core-site.xml': ng_extra['xml']['core-site'],
+            '/etc/hadoop/conf/hdfs-site.xml': ng_extra['xml']['hdfs-site'],
         }
 
         sp_home = self._spark_home(cluster)
         files_spark = {
-            os.path.join(sp_home, 'conf/spark-env.sh'): extra['sp_master'],
-            os.path.join(sp_home, 'conf/slaves'): extra['sp_slaves'],
-            os.path.join(sp_home,
-                         'conf/spark-defaults.conf'): extra['sp_defaults']
+            os.path.join(sp_home, 'conf/spark-env.sh'): ng_extra['sp_master'],
+            os.path.join(sp_home, 'conf/slaves'): ng_extra['sp_slaves']
         }
 
         files_init = {
-            '/tmp/sahara-hadoop-init.sh': extra['setup_script'],
+            '/tmp/sahara-hadoop-init.sh': ng_extra['setup_script'],
             'id_rsa': cluster.management_private_key,
             'authorized_keys': cluster.management_public_key
         }
@@ -297,7 +231,7 @@ class SparkProvider(p.ProvisioningPluginBase):
                    'sudo chown $USER $HOME/.ssh/id_rsa; '
                    'sudo chmod 600 $HOME/.ssh/id_rsa')
 
-        storage_paths = instance.storage_paths()
+        storage_paths = instance.node_group.storage_paths()
         dn_path = ' '.join(c_helper.make_hadoop_path(storage_paths,
                                                      '/dfs/dn'))
         nn_path = ' '.join(c_helper.make_hadoop_path(storage_paths,
@@ -339,9 +273,7 @@ class SparkProvider(p.ProvisioningPluginBase):
 
             self._write_topology_data(r, cluster, extra)
             self._push_master_configs(r, cluster, extra, instance)
-            self._push_cleanup_job(r, cluster, extra, instance)
 
-    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _push_configs_to_existing_node(self, cluster, extra, instance):
         node_processes = instance.node_group.node_processes
         need_update_hadoop = (c_helper.is_data_locality_enabled(cluster) or
@@ -350,18 +282,15 @@ class SparkProvider(p.ProvisioningPluginBase):
                              'slave' in node_processes)
 
         if need_update_spark:
+            ng_extra = extra[instance.node_group.id]
             sp_home = self._spark_home(cluster)
             files = {
                 os.path.join(sp_home,
-                             'conf/spark-env.sh'): extra['sp_master'],
-                os.path.join(sp_home, 'conf/slaves'): extra['sp_slaves'],
-                os.path.join(
-                    sp_home,
-                    'conf/spark-defaults.conf'): extra['sp_defaults']
+                             'conf/spark-env.sh'): ng_extra['sp_master'],
+                os.path.join(sp_home, 'conf/slaves'): ng_extra['sp_slaves'],
             }
             r = remote.get_remote(instance)
             r.write_files_to(files)
-            self._push_cleanup_job(r, cluster, extra, instance)
         if need_update_hadoop:
             with remote.get_remote(instance) as r:
                 self._write_topology_data(r, cluster, extra)
@@ -374,27 +303,14 @@ class SparkProvider(p.ProvisioningPluginBase):
 
     def _push_master_configs(self, r, cluster, extra, instance):
         node_processes = instance.node_group.node_processes
+
         if 'namenode' in node_processes:
             self._push_namenode_configs(cluster, r)
 
-    def _push_cleanup_job(self, r, cluster, extra, instance):
-        node_processes = instance.node_group.node_processes
-        if 'master' in node_processes:
-            if extra['job_cleanup']['valid']:
-                r.write_file_to('/etc/hadoop/tmp-cleanup.sh',
-                                extra['job_cleanup']['script'])
-                r.execute_command("chmod 755 /etc/hadoop/tmp-cleanup.sh")
-                cmd = 'sudo sh -c \'echo "%s" > /etc/cron.d/spark-cleanup\''
-                r.execute_command(cmd % extra['job_cleanup']['cron'])
-            else:
-                r.execute_command("sudo rm -f /etc/hadoop/tmp-cleanup.sh")
-                r.execute_command("sudo rm -f /etc/crond.d/spark-cleanup")
-
     def _push_namenode_configs(self, cluster, r):
         r.write_file_to('/etc/hadoop/dn.incl',
                         utils.generate_fqdn_host_names(
                             utils.get_instances(cluster, "datanode")))
-        r.write_file_to('/etc/hadoop/dn.excl', '')
 
     def _set_cluster_info(self, cluster):
         nn = utils.get_instance(cluster, "namenode")
@@ -402,21 +318,20 @@ class SparkProvider(p.ProvisioningPluginBase):
         info = {}
 
         if nn:
-            address = utils.get_config_value_or_default(
+            address = c_helper.get_config_value(
                 'HDFS', 'dfs.http.address', cluster)
             port = address[address.rfind(':') + 1:]
             info['HDFS'] = {
-                'Web UI': 'http://%s:%s' % (nn.get_ip_or_dns_name(), port)
+                'Web UI': 'http://%s:%s' % (nn.management_ip, port)
             }
             info['HDFS']['NameNode'] = 'hdfs://%s:8020' % nn.hostname()
 
         if sp_master:
-            port = utils.get_config_value_or_default(
+            port = c_helper.get_config_value(
                 'Spark', 'Master webui port', cluster)
             if port is not None:
                 info['Spark'] = {
-                    'Web UI': 'http://%s:%s' % (
-                        sp_master.get_ip_or_dns_name(), port)
+                    'Web UI': 'http://%s:%s' % (sp_master.management_ip, port)
                 }
         ctx = context.ctx()
         conductor.cluster_update(ctx, cluster, {'info': info})
@@ -458,13 +373,11 @@ class SparkProvider(p.ProvisioningPluginBase):
         self._setup_instances(cluster, instances)
         nn = utils.get_instance(cluster, "namenode")
         run.refresh_nodes(remote.get_remote(nn), "dfsadmin")
-        dn_instances = [instance for instance in instances if
-                        'datanode' in instance.node_group.node_processes]
-        self._start_datanode_processes(dn_instances)
+        self._start_slave_datanode_processes(instances)
 
-        swift_helper.install_ssl_certs(instances)
         run.start_spark_master(r_master, self._spark_home(cluster))
-        LOG.info("Spark master service has been restarted")
+        LOG.info(_LI("Spark master service at '%s' has been restarted"),
+                 master.hostname())
 
     def _get_scalable_processes(self):
         return ["datanode", "slave"]
@@ -495,9 +408,8 @@ class SparkProvider(p.ProvisioningPluginBase):
                         ' '.join(ng.node_processes))
 
         dn_amount = len(utils.get_instances(cluster, "datanode"))
-        rep_factor = utils.get_config_value_or_default('HDFS',
-                                                       "dfs.replication",
-                                                       cluster)
+        rep_factor = c_helper.get_config_value('HDFS', "dfs.replication",
+                                               cluster)
 
         if dn_to_delete > 0 and dn_amount - dn_to_delete < rep_factor:
             raise ex.ClusterCannotBeScaled(
@@ -507,69 +419,7 @@ class SparkProvider(p.ProvisioningPluginBase):
                 rep_factor)
 
     def get_edp_engine(self, cluster, job_type):
-        if edp_engine.EdpEngine.job_type_supported(job_type):
+        if job_type in edp_engine.EdpEngine.get_supported_job_types():
             return edp_engine.EdpEngine(cluster)
 
-        if shell_engine.ShellEngine.job_type_supported(job_type):
-            return shell_engine.ShellEngine(cluster)
-
         return None
-
-    def get_edp_job_types(self, versions=None):
-        res = {}
-        for vers in self.get_versions():
-            if not versions or vers in versions:
-                res[vers] = shell_engine.ShellEngine.get_supported_job_types()
-
-                if edp_engine.EdpEngine.edp_supported(vers):
-                    res[vers].extend(
-                        edp_engine.EdpEngine.get_supported_job_types())
-
-        return res
-
-    def get_edp_config_hints(self, job_type, version):
-        if (edp_engine.EdpEngine.edp_supported(version) and
-                edp_engine.EdpEngine.job_type_supported(job_type)):
-            return edp_engine.EdpEngine.get_possible_job_config(job_type)
-
-        if shell_engine.ShellEngine.job_type_supported(job_type):
-            return shell_engine.ShellEngine.get_possible_job_config(job_type)
-
-        return {}
-
-    def get_open_ports(self, node_group):
-        cluster = node_group.cluster
-        ports_map = {
-            'namenode': [8020, 50070, 50470],
-            'datanode': [50010, 1004, 50075, 1006, 50020],
-            'master': [
-                int(utils.get_config_value_or_default("Spark", "Master port",
-                                                      cluster)),
-                int(utils.get_config_value_or_default("Spark",
-                                                      "Master webui port",
-                                                      cluster)),
-            ],
-            'slave': [
-                int(utils.get_config_value_or_default("Spark",
-                                                      "Worker webui port",
-                                                      cluster))
-            ]
-        }
-
-        ports = []
-        for process in node_group.node_processes:
-            if process in ports_map:
-                ports.extend(ports_map[process])
-
-        return ports
-
-    def recommend_configs(self, cluster, scaling=False):
-        want_to_configure = {
-            'cluster_configs': {
-                'dfs.replication': ('HDFS', 'dfs.replication')
-            }
-        }
-        provider = ru.HadoopAutoConfigsProvider(
-            want_to_configure, self.get_configs(
-                cluster.hadoop_version), cluster, scaling)
-        provider.apply_recommended_configs()
