@@ -35,43 +35,51 @@ class HDP2GatingTest(swift.SwiftTest, scaling.ScalingTest,
         super(HDP2GatingTest, self).setUp()
         self.cluster_id = None
         self.cluster_template_id = None
+        self.ng_template_ids = []
 
-    def get_plugin_config(self):
-        return cfg.ITConfig().hdp2_config
+    def _prepare_test(self):
+        self.hdp2_config = cfg.ITConfig().hdp2_config
+        self.floating_ip_pool = self.common_config.FLOATING_IP_POOL
+        self.internal_neutron_net = None
+        if self.common_config.NEUTRON_ENABLED:
+            self.internal_neutron_net = self.get_internal_neutron_net_id()
+            self.floating_ip_pool = (
+                self.get_floating_ip_pool_id_for_neutron_net())
+
+        self.hdp2_config.IMAGE_ID, self.hdp2_config.SSH_USERNAME = (
+            self.get_image_id_and_ssh_username(self.hdp2_config))
 
     @b.errormsg("Failure while 'rm-nn' node group template creation: ")
     def _create_rm_nn_ng_template(self):
         template = {
             'name': 'test-node-group-template-hdp2-rm-nn',
-            'plugin_config': self.plugin_config,
+            'plugin_config': self.hdp2_config,
             'description': 'test node group template for HDP plugin',
-            'node_processes': self.plugin_config.MASTER_NODE_PROCESSES,
+            'node_processes': self.hdp2_config.MASTER_NODE_PROCESSES,
             'floating_ip_pool': self.floating_ip_pool,
-            'auto_security_group': True,
             'node_configs': {}
         }
         self.ng_tmpl_rm_nn_id = self.create_node_group_template(**template)
-        self.addCleanup(self.delete_node_group_template, self.ng_tmpl_rm_nn_id)
+        self.ng_template_ids.append(self.ng_tmpl_rm_nn_id)
 
     @b.errormsg("Failure while 'nm-dn' node group template creation: ")
     def _create_nm_dn_ng_template(self):
         template = {
             'name': 'test-node-group-template-hdp2-nm-dn',
-            'plugin_config': self.plugin_config,
+            'plugin_config': self.hdp2_config,
             'description': 'test node group template for HDP plugin',
-            'node_processes': self.plugin_config.WORKER_NODE_PROCESSES,
+            'node_processes': self.hdp2_config.WORKER_NODE_PROCESSES,
             'floating_ip_pool': self.floating_ip_pool,
-            'auto_security_group': True,
             'node_configs': {}
         }
         self.ng_tmpl_nm_dn_id = self.create_node_group_template(**template)
-        self.addCleanup(self.delete_node_group_template, self.ng_tmpl_nm_dn_id)
+        self.ng_template_ids.append(self.ng_tmpl_nm_dn_id)
 
     @b.errormsg("Failure while cluster template creation: ")
     def _create_cluster_template(self):
         template = {
             'name': 'test-cluster-template-hdp2',
-            'plugin_config': self.plugin_config,
+            'plugin_config': self.hdp2_config,
             'description': 'test cluster template for HDP plugin',
             'cluster_configs': {
                 'YARN': {
@@ -93,25 +101,22 @@ class HDP2GatingTest(swift.SwiftTest, scaling.ScalingTest,
             'net_id': self.internal_neutron_net
         }
         self.cluster_template_id = self.create_cluster_template(**template)
-        self.addCleanup(self.delete_cluster_template, self.cluster_template_id)
 
     @b.errormsg("Failure while cluster creation: ")
     def _create_cluster(self):
         cluster_name = '%s-%s-v2' % (self.common_config.CLUSTER_NAME,
-                                     self.plugin_config.PLUGIN_NAME)
+                                     self.hdp2_config.PLUGIN_NAME)
         cluster = {
             'name': cluster_name,
-            'plugin_config': self.plugin_config,
+            'plugin_config': self.hdp2_config,
             'cluster_template_id': self.cluster_template_id,
             'description': 'test cluster',
             'cluster_configs': {}
         }
-        cluster_id = self.create_cluster(**cluster)
-        self.addCleanup(self.delete_cluster, cluster_id)
-        self.poll_cluster_state(cluster_id)
-        self.cluster_info = self.get_cluster_info(self.plugin_config)
+        self.create_cluster(**cluster)
+        self.cluster_info = self.get_cluster_info(self.hdp2_config)
         self.await_active_workers_for_namenode(self.cluster_info['node_info'],
-                                               self.plugin_config)
+                                               self.hdp2_config)
 
     @b.errormsg("Failure during check of Swift availability: ")
     def _check_swift(self):
@@ -119,60 +124,48 @@ class HDP2GatingTest(swift.SwiftTest, scaling.ScalingTest,
 
     @b.errormsg("Failure while EDP testing: ")
     def _check_edp(self):
-        self.poll_jobs_status(list(self._run_edp_test()))
+        self._edp_test()
 
-    def _run_edp_test(self):
+    def _edp_test(self):
         # check pig
         pig_job = self.edp_info.read_pig_example_script()
         pig_lib = self.edp_info.read_pig_example_jar()
-        yield self.edp_testing(
-            job_type=utils_edp.JOB_TYPE_PIG,
-            job_data_list=[{'pig': pig_job}],
-            lib_data_list=[{'jar': pig_lib}],
-            swift_binaries=True,
-            hdfs_local_output=True)
+
+        self.edp_testing(job_type=utils_edp.JOB_TYPE_PIG,
+                         job_data_list=[{'pig': pig_job}],
+                         lib_data_list=[{'jar': pig_lib}],
+                         swift_binaries=True,
+                         hdfs_local_output=True)
 
         # check mapreduce
         mapreduce_jar = self.edp_info.read_mapreduce_example_jar()
         mapreduce_configs = self.edp_info.mapreduce_example_configs()
-        yield self.edp_testing(
-            job_type=utils_edp.JOB_TYPE_MAPREDUCE,
-            job_data_list=[],
-            lib_data_list=[{'jar': mapreduce_jar}],
-            configs=mapreduce_configs,
-            swift_binaries=True,
-            hdfs_local_output=True)
+        self.edp_testing(job_type=utils_edp.JOB_TYPE_MAPREDUCE,
+                         job_data_list=[],
+                         lib_data_list=[{'jar': mapreduce_jar}],
+                         configs=mapreduce_configs,
+                         swift_binaries=True,
+                         hdfs_local_output=True)
 
         # check mapreduce streaming
-        yield self.edp_testing(
-            job_type=utils_edp.JOB_TYPE_MAPREDUCE_STREAMING,
-            job_data_list=[],
-            lib_data_list=[],
-            configs=self.edp_info.mapreduce_streaming_configs())
+        self.edp_testing(job_type=utils_edp.JOB_TYPE_MAPREDUCE_STREAMING,
+                         job_data_list=[],
+                         lib_data_list=[],
+                         configs=self.edp_info.mapreduce_streaming_configs())
 
         # check java
         java_jar = self.edp_info.read_java_example_lib(2)
         java_configs = self.edp_info.java_example_configs(2)
-        yield self.edp_testing(
-            utils_edp.JOB_TYPE_JAVA,
-            job_data_list=[],
-            lib_data_list=[{'jar': java_jar}],
-            configs=java_configs)
-
-        # check shell
-        shell_script_data = self.edp_info.read_shell_example_script()
-        shell_file_data = self.edp_info.read_shell_example_text_file()
-        yield self.edp_testing(
-            job_type=utils_edp.JOB_TYPE_SHELL,
-            job_data_list=[{'script': shell_script_data}],
-            lib_data_list=[{'text': shell_file_data}],
-            configs=self.edp_info.shell_example_configs())
+        self.edp_testing(utils_edp.JOB_TYPE_JAVA,
+                         job_data_list=[],
+                         lib_data_list=[{'jar': java_jar}],
+                         configs=java_configs)
 
     @b.errormsg("Failure while cluster scaling: ")
     def _check_scaling(self):
         datanode_count_after_resizing = (
             self.cluster_info['node_info']['datanode_count']
-            + self.plugin_config.SCALE_EXISTING_NG_COUNT)
+            + self.hdp_config.SCALE_EXISTING_NG_COUNT)
         change_list = [
             {
                 'operation': 'resize',
@@ -182,7 +175,7 @@ class HDP2GatingTest(swift.SwiftTest, scaling.ScalingTest,
             {
                 'operation': 'add',
                 'info': ['new-worker-node-tt-dn',
-                         self.plugin_config.SCALE_NEW_NG_COUNT,
+                         self.hdp2_config.SCALE_NEW_NG_COUNT,
                          '%s' % self.ng_tmpl_nm_dn_id]
             }
         ]
@@ -190,7 +183,7 @@ class HDP2GatingTest(swift.SwiftTest, scaling.ScalingTest,
         self.cluster_info = self.cluster_scaling(self.cluster_info,
                                                  change_list)
         self.await_active_workers_for_namenode(self.cluster_info['node_info'],
-                                               self.plugin_config)
+                                               self.hdp2_config)
 
     @b.errormsg(
         "Failure during check of Swift availability after cluster scaling: ")
@@ -199,25 +192,27 @@ class HDP2GatingTest(swift.SwiftTest, scaling.ScalingTest,
 
     @b.errormsg("Failure while EDP testing after cluster scaling: ")
     def _check_edp_after_scaling(self):
-        self._check_edp()
+        self._edp_test()
 
     @testcase.attr('hdp2')
     @testcase.skipIf(config.SKIP_ALL_TESTS_FOR_PLUGIN,
                      'All tests for HDP2 plugin were skipped')
     def test_hdp2_plugin_gating(self):
+        self._prepare_test()
         self._create_rm_nn_ng_template()
         self._create_nm_dn_ng_template()
         self._create_cluster_template()
         self._create_cluster()
-        self._test_event_log(self.cluster_id)
+
         self._check_swift()
         self._check_edp()
 
-        if not self.plugin_config.SKIP_SCALING_TEST:
+        if not self.hdp2_config.SKIP_SCALING_TEST:
             self._check_scaling()
-            self._test_event_log(self.cluster_id)
             self._check_swift_after_scaling()
             self._check_edp_after_scaling()
 
     def tearDown(self):
+        self.delete_objects(self.cluster_id, self.cluster_template_id,
+                            self.ng_template_ids)
         super(HDP2GatingTest, self).tearDown()
