@@ -13,7 +13,42 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# job execution status
+JOB_STATUS_DONEWITHERROR = 'DONEWITHERROR'
+JOB_STATUS_FAILED = 'FAILED'
+JOB_STATUS_KILLED = 'KILLED'
+JOB_STATUS_PENDING = 'PENDING'
+JOB_STATUS_RUNNING = 'RUNNING'
+JOB_STATUS_SUCCEEDED = 'SUCCEEDED'
+# statuses for terminated jobs
+JOB_STATUSES_TERMINATED = [
+    JOB_STATUS_DONEWITHERROR,
+    JOB_STATUS_FAILED,
+    JOB_STATUS_KILLED,
+    JOB_STATUS_SUCCEEDED
+]
+# job type separator character
 JOB_TYPE_SEP = '.'
+# job sub types available
+JOB_SUBTYPE_STREAMING = 'Streaming'
+JOB_SUBTYPE_NONE = ''
+# job types available
+JOB_TYPE_HIVE = 'Hive'
+JOB_TYPE_JAVA = 'Java'
+JOB_TYPE_MAPREDUCE = 'MapReduce'
+JOB_TYPE_SPARK = 'Spark'
+JOB_TYPE_MAPREDUCE_STREAMING = (JOB_TYPE_MAPREDUCE + JOB_TYPE_SEP +
+                                JOB_SUBTYPE_STREAMING)
+JOB_TYPE_PIG = 'Pig'
+# job type groupings available
+JOB_TYPES_ALL = [
+    JOB_TYPE_HIVE,
+    JOB_TYPE_JAVA,
+    JOB_TYPE_MAPREDUCE,
+    JOB_TYPE_MAPREDUCE_STREAMING,
+    JOB_TYPE_PIG,
+    JOB_TYPE_SPARK
+]
 
 
 def split_job_type(job_type):
